==> office-ui-fabric-react-0.49.0.tgz: package/lib-amd/demo/pages/SliderPage/SliderPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../components/index', './examples/Slider.Basic.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, Slider_Basic_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var SliderBasicExampleCode = require('./examples/Slider.Basic.Example.tsx');
    var SliderPage = (function (_super) {
        __extends(SliderPage, _super);
        function SliderPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'Slider');
        }
        SliderPage.prototype.render = function () {
            return (React.createElement(index_1.ComponentPage, {title: 'Slider', componentName: 'SliderExample', exampleCards: [
                React.createElement(index_1.ExampleCard, {title: 'Slider', code: SliderBasicExampleCode}, React.createElement(Slider_Basic_Example_1.SliderBasicExample, null))
            ], propertiesTables: [
                React.createElement(index_1.PropertiesTableSet, {componentName: 'Slider'})
            ], overview: React.createElement("div", null, React.createElement("span", null, "Sliders provide a way for users to choose a value or an option.")), route: this._url}));
        };
        return SliderPage;
    }(React.Component));
    exports.SliderPage = SliderPage;
});

==> office-ui-fabric-react-0.52.2.tgz: package/lib-amd/demo/pages/SliderPage/SliderPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../components/index', './examples/Slider.Basic.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, Slider_Basic_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var SliderBasicExampleCode = require('./examples/Slider.Basic.Example.tsx');
    var SliderPage = (function (_super) {
        __extends(SliderPage, _super);
        function SliderPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'Slider');
        }
        SliderPage.prototype.render = function () {
            return (React.createElement(index_1.ComponentPage, {title: 'Slider', componentName: 'SliderExample', exampleCards: [
                React.createElement(index_1.ExampleCard, {title: 'Slider', code: SliderBasicExampleCode}, React.createElement(Slider_Basic_Example_1.SliderBasicExample, null))
            ], propertiesTables: [
                React.createElement(index_1.PropertiesTableSet, {componentName: 'Slider'})
            ], overview: React.createElement("div", null, React.createElement("span", null, "Sliders provide a way for users to choose a value or an option.")), route: this._url, isHeaderVisible: this.props.isHeaderVisible}));
        };
        return SliderPage;
    }(React.Component));
    exports.SliderPage = SliderPage;
});
